@@ -5,8 +5,14 @@
 # @File    : __init__.py.py
 # @Desc    :
 
-from web_extractor.test import (
-    cs_test
-)
 
-from web_extractor.new_extractor import NewsExtractor
\ No newline at end of file
+"""
+新闻类站点自动化抽取
+"""
+from web_extractor.new_extractor import NewsExtractor
+
+
+"""
+电商类站点自动化抽取
+"""
+from web_extractor.shop_extractor import ShopExtractor
\ No newline at end of file
