@@ -1,20 +1,35 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+# @Time    : 2020/5/2 12:16
+# @Author  : justin.郑 3907721@qq.com
+# @File    : TitleExtractor.py
+# @Desc    : 新闻文章标题抽取
+
 import re
 from lxml.html import HtmlElement
 from web_extractor.cons import TITLE_SPLIT_CHAR_PATTERN, TITLE_HTAG_XPATH
-from web_extractor.utils import config
+from web_extractor.new_extractor.new_utils import config
 
 
 class TitleExtractor:
-    def extract_by_xpath(self, element, title_xpath):
+    def extract(self, element: HtmlElement, title_xpath: str = ''):
+        title_xpath = title_xpath or config.get('title', {}).get('xpath')
+        title = self.extract_from_xpath(element, title_xpath) \
+                or self.extract_from_title(element) \
+                or self.extract_from_htag(element)
+        return title.strip()
+
+    def extract_from_xpath(self, element, title_xpath):
         if title_xpath:
             title_list = element.xpath(title_xpath)
             if title_list:
-                return title_list[0]
+                title = re.split(TITLE_SPLIT_CHAR_PATTERN, title_list[0])
+                return title[0]
             else:
                 return ''
         return ''
 
-    def extract_by_title(self, element):
+    def extract_from_title(self, element):
         title_list = element.xpath('//title/text()')
         if not title_list:
             return ''
@@ -24,13 +39,10 @@ class TitleExtractor:
         else:
             return ''
 
-    def extract_by_htag(self, element):
+    def extract_from_htag(self, element):
         title_list = element.xpath(TITLE_HTAG_XPATH)
         if not title_list:
             return ''
         return title_list[0]
 
-    def extract(self, element: HtmlElement, title_xpath: str = ''):
-        title_xpath = title_xpath or config.get('title', {}).get('xpath')
-        title = self.extract_by_xpath(element, title_xpath) or self.extract_by_title(element) or self.extract_by_htag(element)
-        return title.strip()
+
